@@ -23,7 +23,7 @@ namespace rL1 {
                     grad -= A.row(i).t() * (u[i] * scale[i]);
                 }
             }
-            ord = stable_sort_index(abs(grad), 1);
+            ord = stable_sort_index(abs(grad), "descend");
             j = -1;
         }
         return j;
